@@ -3,16 +3,13 @@
 A simple example of a calculator program.
 This could be used as inspiration for a REPL.
 """
-from __future__ import unicode_literals
-
 from prompt_toolkit.application import Application
 from prompt_toolkit.document import Document
-from prompt_toolkit.filters import has_focus
 from prompt_toolkit.key_binding import KeyBindings
 from prompt_toolkit.layout.containers import HSplit, Window
 from prompt_toolkit.layout.layout import Layout
 from prompt_toolkit.styles import Style
-from prompt_toolkit.widgets import TextArea, SearchToolbar
+from prompt_toolkit.widgets import SearchToolbar, TextArea
 
 help_text = """
 Type any expression (e.g. "4 + 4") followed by enter to execute.
@@ -24,17 +21,24 @@ def main():
     # The layout.
     search_field = SearchToolbar()  # For reverse search.
 
-    output_field = TextArea(style='class:output-field', text=help_text)
+    output_field = TextArea(style="class:output-field", text=help_text)
     input_field = TextArea(
-        height=1, prompt='>>> ', style='class:input-field', multiline=False,
-        wrap_lines=False, search_field=search_field)
+        height=1,
+        prompt=">>> ",
+        style="class:input-field",
+        multiline=False,
+        wrap_lines=False,
+        search_field=search_field,
+    )
 
-    container = HSplit([
-        output_field,
-        Window(height=1, char='-', style='class:line'),
-        input_field,
-        search_field,
-    ])
+    container = HSplit(
+        [
+            output_field,
+            Window(height=1, char="-", style="class:line"),
+            input_field,
+            search_field,
+        ]
+    )
 
     # Attach accept handler to the input field. We do this by assigning the
     # handler to the `TextArea` that we created earlier. it is also possible to
@@ -45,34 +49,37 @@ def main():
     def accept(buff):
         # Evaluate "calculator" expression.
         try:
-            output = '\n\nIn:  {}\nOut: {}'.format(
-                input_field.text,
-                eval(input_field.text))  # Don't do 'eval' in real code!
+            output = "\n\nIn:  {}\nOut: {}".format(
+                input_field.text, eval(input_field.text)
+            )  # Don't do 'eval' in real code!
         except BaseException as e:
-            output = '\n\n{}'.format(e)
+            output = f"\n\n{e}"
         new_text = output_field.text + output
 
         # Add text to output buffer.
         output_field.buffer.document = Document(
-            text=new_text, cursor_position=len(new_text))
+            text=new_text, cursor_position=len(new_text)
+        )
 
     input_field.accept_handler = accept
 
     # The key bindings.
     kb = KeyBindings()
 
-    @kb.add('c-c')
-    @kb.add('c-q')
+    @kb.add("c-c")
+    @kb.add("c-q")
     def _(event):
-        " Pressing Ctrl-Q or Ctrl-C will exit the user interface. "
+        "Pressing Ctrl-Q or Ctrl-C will exit the user interface."
         event.app.exit()
 
     # Style.
-    style = Style([
-        ('output-field', 'bg:#000044 #ffffff'),
-        ('input-field', 'bg:#000000 #ffffff'),
-        ('line',        '#004400'),
-    ])
+    style = Style(
+        [
+            ("output-field", "bg:#000044 #ffffff"),
+            ("input-field", "bg:#000000 #ffffff"),
+            ("line", "#004400"),
+        ]
+    )
 
     # Run application.
     application = Application(
@@ -80,10 +87,11 @@ def main():
         key_bindings=kb,
         style=style,
         mouse_support=True,
-        full_screen=True)
+        full_screen=True,
+    )
 
     application.run()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
