@@ -11,7 +11,7 @@ def get_prompt():
     "Tokens to be shown before the prompt."
     now = datetime.datetime.now()
     return [
-        ("bg:#008800 #ffffff", "%s:%s:%s" % (now.hour, now.minute, now.second)),
+        ("bg:#008800 #ffffff", f"{now.hour}:{now.minute}:{now.second}"),
         ("bg:cornsilk fg:maroon", " Enter something: "),
     ]
 
